==> php-5.1.4.tar.bz2: php-5.1.4/ext/date/lib/fallbackmap.h <==
	{ "sst",   0,  -11,  "Pacific/Apia" },
	{ "hst",   0,  -10,  "Pacific/Honolulu" },
	{ "akst",  0,   -9,  "America/Anchorage" },
	{ "akdt",  1,   -8,  "America/Anchorage" },
	{ "pst",   0,   -8,  "America/Los_Angeles" },
	{ "pdt",   1,   -7,  "America/Los_Angeles" },
	{ "mst",   0,   -7,  "America/Denver" },
	{ "mdt",   1,   -6,  "America/Denver" },
	{ "cst",   0,   -6,  "America/Chicago" },
	{ "cdt",   1,   -5,  "America/Chicago" },
	{ "est",   0,   -5,  "America/New_York" },
	{ "edt",   1,   -4,  "America/New_York" },
	{ "ast",   0,   -4,  "America/Halifax" },
	{ "adt",   1,   -3,  "America/Halifax" },
	{ "brt",   0,   -3,  "America/Sao_Paulo" },
	{ "brst",  1,   -2,  "America/Sao_Paulo" },
	{ "azost", 0,   -1,  "Atlantic/Azores" },
	{ "azodt", 1,    0,  "Atlantic/Azores" },
	{ "gmt",   0,    0,  "Europe/London" },
	{ "bst",   1,    1,  "Europe/London" },
	{ "cet",   0,    1,  "Europe/Paris" },
	{ "cest",  1,    2,  "Europe/Paris" },
	{ "eet",   0,    2,  "Europe/Helsinki" },
	{ "eest",  1,    3,  "Europe/Helsinki" },
	{ "msk",   0,    3,  "Europe/Moscow" },
	{ "msd",   1,    4,  "Europe/Moscow" },
	{ "gst",   0,    4,  "Asia/Dubai" },
	{ "pkt",   0,    5,  "Asia/Karachi" },
	{ "ist",   0,  5.5,  "Asia/Calcutta" },
	{ "npt",   0, 5.75,  "Asia/Katmandu" },
	{ "yekt",  1,    6,  "Asia/Yekaterinburg" },
	{ "novst", 1,    7,  "Asia/Novosibirsk" },
	{ "krat",  0,    7,  "Asia/Krasnoyarsk" },
	{ "krast", 1,    8,  "Asia/Krasnoyarsk" },
	{ "jst",   0,    9,  "Asia/Tokyo" },
	{ "est",   0,   10,  "Australia/Melbourne" },
	{ "cst",   1, 10.5,  "Australia/Adelaide" },
	{ "est",   1,   11,  "Australia/Melbourne" },
	{ "nzst",  0,   12,  "Pacific/Auckland" },
	{ "nzdt",  1,   13,  "Pacific/Auckland" },

==> php-5.3.29.tar.bz2: php-5.3.29/ext/date/lib/fallbackmap.h <==
	{ "sst",   0,  -11,  "Pacific/Apia" },
	{ "hst",   0,  -10,  "Pacific/Honolulu" },
	{ "akst",  0,   -9,  "America/Anchorage" },
	{ "akdt",  1,   -8,  "America/Anchorage" },
	{ "pst",   0,   -8,  "America/Los_Angeles" },
	{ "pdt",   1,   -7,  "America/Los_Angeles" },
	{ "mst",   0,   -7,  "America/Denver" },
	{ "mdt",   1,   -6,  "America/Denver" },
	{ "cst",   0,   -6,  "America/Chicago" },
	{ "cdt",   1,   -5,  "America/Chicago" },
	{ "est",   0,   -5,  "America/New_York" },
	{ "edt",   1,   -4,  "America/New_York" },
	{ "ast",   0,   -4,  "America/Halifax" },
	{ "adt",   1,   -3,  "America/Halifax" },
	{ "brt",   0,   -3,  "America/Sao_Paulo" },
	{ "brst",  1,   -2,  "America/Sao_Paulo" },
	{ "azost", 0,   -1,  "Atlantic/Azores" },
	{ "azodt", 1,    0,  "Atlantic/Azores" },
	{ "gmt",   0,    0,  "Europe/London" },
	{ "bst",   1,    1,  "Europe/London" },
	{ "cet",   0,    1,  "Europe/Paris" },
	{ "cest",  1,    2,  "Europe/Paris" },
	{ "eet",   0,    2,  "Europe/Helsinki" },
	{ "eest",  1,    3,  "Europe/Helsinki" },
	{ "msk",   0,    3,  "Europe/Moscow" },
	{ "msd",   1,    4,  "Europe/Moscow" },
	{ "gst",   0,    4,  "Asia/Dubai" },
	{ "pkt",   0,    5,  "Asia/Karachi" },
	{ "ist",   0,  5.5,  "Asia/Kolkata" },
	{ "npt",   0, 5.75,  "Asia/Katmandu" },
	{ "yekt",  1,    6,  "Asia/Yekaterinburg" },
	{ "novst", 1,    7,  "Asia/Novosibirsk" },
	{ "krat",  0,    7,  "Asia/Krasnoyarsk" },
	{ "krast", 1,    8,  "Asia/Krasnoyarsk" },
	{ "jst",   0,    9,  "Asia/Tokyo" },
	{ "est",   0,   10,  "Australia/Melbourne" },
	{ "cst",   1, 10.5,  "Australia/Adelaide" },
	{ "est",   1,   11,  "Australia/Melbourne" },
	{ "nzst",  0,   12,  "Pacific/Auckland" },
	{ "nzdt",  1,   13,  "Pacific/Auckland" },
